﻿using Hotline.Api.Sdk;
using MapsterMapper;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Sharing.Share.Dtos.WebPortal;
using Sharing.WebCore;
using Sharing.WebPortal.Dtos;
using XF.Domain.Repository;

namespace Sharing.WebPortal.Controllers
{
    public class UserController : BaseController
    {
        private readonly IMapper _mapper;
        private readonly IRepository<WebUserRegister> _webUserRegisterRepository;
        private readonly IRepository<WebUserAuth> _webUserAuthRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="mapper"></param>
        /// <param name="webUserRegisterRepository"></param>
        /// <param name="webUserAuthRepository"></param>
        public UserController(IMapper mapper,
             IRepository<WebUserRegister> webUserRegisterRepository,
            IRepository<WebUserAuth> webUserAuthRepository)
        {
            _mapper = mapper;
            _webUserRegisterRepository = webUserRegisterRepository;
            _webUserAuthRepository = webUserAuthRepository;
        }

        /// <summary>
        /// 添加统一认证用户数据
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [AllowAnonymous]
        [HttpPost("adduserauth")]
        public async Task<DeReponse<string>> AddUserAuth([FromBody] UserModelDto dto)
        {
            bool bResult = false;
            // 唯一记录ID
            string id = dto.id;
            // 注册用户ID
            string webUserID = "";
            // 统一认证用户注册ID
            string wUAID = "";
            //查询是否有注册用户
            var dataUser = await _webUserAuthRepository.GetAsync(p => p.DataId == id, HttpContext.RequestAborted);
            if (dataUser != null)
            {
                webUserID = dataUser.WebUserID;
                wUAID = dataUser.Id;
            }
            //没有注册用户添加数据
            if (string.IsNullOrEmpty(webUserID))
            {
                var userRegister = _mapper.Map<WebUserRegister>(dto);
                userRegister.RegDate = DateTime.Now;
                userRegister.LastDate = DateTime.Now;
                webUserID = await _webUserRegisterRepository.AddAsync(userRegister, HttpContext.RequestAborted);
            }

            //统一认证数据
            var userAuth = _mapper.Map<WebUserAuth>(dto);
            if (!string.IsNullOrEmpty(wUAID))
            {
                //修改数据
                userAuth.Id = wUAID;
                await _webUserAuthRepository.UpdateAsync(userAuth, HttpContext.RequestAborted);
                bResult = true;
            }
            else
            {
                //新增数据
                userAuth.WebGUID = Guid.NewGuid().ToString();
                userAuth.WebUserID = webUserID;
                var addId = await _webUserAuthRepository.AddAsync(userAuth, HttpContext.RequestAborted);
                if (string.IsNullOrEmpty(addId))
                    bResult = true;
            }
            //判断是否成功
            if (bResult)
                return DeReponse<string>.Success(webUserID);
            else
                return DeReponse<string>.Failed(null);
        }
    }
}
